@@ -13,11 +13,11 @@ try:
     from . import pathlib3x
 except (ImportError, ModuleNotFoundError):  # pragma: no cover
     # imports for doctest
-    import __init__conf__                   # type: ignore  # pragma: no cover
-    import pathlib3x                        # type: ignore  # pragma: no cover
+    import __init__conf__  # type: ignore  # pragma: no cover
+    import pathlib3x  # type: ignore  # pragma: no cover
 
 # CONSTANTS
-CLICK_CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
+CLICK_CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 
 
 def info() -> None:
@@ -30,23 +30,23 @@ def info() -> None:
 
 
 @click.group(help=__init__conf__.title, context_settings=CLICK_CONTEXT_SETTINGS)
-@click.version_option(version=__init__conf__.version,
-                      prog_name=__init__conf__.shell_command,
-                      message='{} version %(version)s'.format(__init__conf__.shell_command))
-@click.option('--traceback/--no-traceback', is_flag=True, type=bool, default=None, help='return traceback information on cli')
+@click.version_option(
+    version=__init__conf__.version, prog_name=__init__conf__.shell_command, message="{} version %(version)s".format(__init__conf__.shell_command)
+)
+@click.option("--traceback/--no-traceback", is_flag=True, type=bool, default=None, help="return traceback information on cli")
 def cli_main(traceback: Optional[bool] = None) -> None:
     if traceback is not None:
         cli_exit_tools.config.traceback = traceback
 
 
-@cli_main.command('info', context_settings=CLICK_CONTEXT_SETTINGS)
+@cli_main.command("info", context_settings=CLICK_CONTEXT_SETTINGS)
 def cli_info() -> None:
-    """ get program informations """
+    """get program informations"""
     info()
 
 
 # entry point if main
-if __name__ == '__main__':
+if __name__ == "__main__":
     try:
         cli_main()
     except Exception as exc:
